# insilicoSV: a framework for structural variant simulation 

## Overview

TODO

## Installation

Prerequisite: Python 3.8 and up - [Install](https://www.python.org/downloads/)

Installation using pip:

* `$ pip install insilicosv`

## To Run
```
insilicosv <reference_fasta> <config_yml> <output_prefix>
```

## Documentation
For documentation outlining the different features of insilicoSV along with usage examples and data resources, please refer to the wiki:
<!-- toc -->
- [Input guidelines](docs/input_guidelines.md)
- [Example Use Cases](docs/example_use_cases.md)
- [SV Grammar](docs/sv_grammar.md)
- [Benchmark Genomes](docs/benchmark_genomes.md)
- [Additional Utilities](docs/automated_pipelines_and_additional_utilities.md)
- [Example SV Visualizations](docs/example_sv_visualizations.md)


## Authors
Chris Rohlicek - crohlice@broadinstitute.org

Nick Jiang - nickj@berkeley.edu

Ilya Shlyakhter - ilya@broadinstitute.org

Victoria Popic - vpopic@broadinstitute.org
